/*******************************************************************************
* File Name: Reg_Disp.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Reg_Disp.h"

#if !defined(Reg_Disp_sts_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: Reg_Disp_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 Reg_Disp_Read(void) 
{ 
    return Reg_Disp_Status;
}


/*******************************************************************************
* Function Name: Reg_Disp_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void Reg_Disp_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    Reg_Disp_Status_Aux_Ctrl |= Reg_Disp_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: Reg_Disp_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void Reg_Disp_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    Reg_Disp_Status_Aux_Ctrl &= (uint8)(~Reg_Disp_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: Reg_Disp_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void Reg_Disp_WriteMask(uint8 mask) 
{
    #if(Reg_Disp_INPUTS < 8u)
    	mask &= ((uint8)(1u << Reg_Disp_INPUTS) - 1u);
	#endif /* End Reg_Disp_INPUTS < 8u */
    Reg_Disp_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: Reg_Disp_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 Reg_Disp_ReadMask(void) 
{
    return Reg_Disp_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
