/*******************************************************************************
* File Name: Vinp.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_Vinp_H) /* Pins Vinp_H */
#define CY_PINS_Vinp_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "Vinp_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    Vinp_Write(uint8 value) ;
void    Vinp_SetDriveMode(uint8 mode) ;
uint8   Vinp_ReadDataReg(void) ;
uint8   Vinp_Read(void) ;
void    Vinp_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   Vinp_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the Vinp_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define Vinp_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define Vinp_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define Vinp_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define Vinp_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define Vinp_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define Vinp_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define Vinp_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define Vinp_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define Vinp_MASK               Vinp__MASK
#define Vinp_SHIFT              Vinp__SHIFT
#define Vinp_WIDTH              1u

/* Interrupt constants */
#if defined(Vinp__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in Vinp_SetInterruptMode() function.
     *  @{
     */
        #define Vinp_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define Vinp_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define Vinp_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define Vinp_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define Vinp_INTR_MASK      (0x01u)
#endif /* (Vinp__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define Vinp_PS                     (* (reg8 *) Vinp__PS)
/* Data Register */
#define Vinp_DR                     (* (reg8 *) Vinp__DR)
/* Port Number */
#define Vinp_PRT_NUM                (* (reg8 *) Vinp__PRT) 
/* Connect to Analog Globals */                                                  
#define Vinp_AG                     (* (reg8 *) Vinp__AG)                       
/* Analog MUX bux enable */
#define Vinp_AMUX                   (* (reg8 *) Vinp__AMUX) 
/* Bidirectional Enable */                                                        
#define Vinp_BIE                    (* (reg8 *) Vinp__BIE)
/* Bit-mask for Aliased Register Access */
#define Vinp_BIT_MASK               (* (reg8 *) Vinp__BIT_MASK)
/* Bypass Enable */
#define Vinp_BYP                    (* (reg8 *) Vinp__BYP)
/* Port wide control signals */                                                   
#define Vinp_CTL                    (* (reg8 *) Vinp__CTL)
/* Drive Modes */
#define Vinp_DM0                    (* (reg8 *) Vinp__DM0) 
#define Vinp_DM1                    (* (reg8 *) Vinp__DM1)
#define Vinp_DM2                    (* (reg8 *) Vinp__DM2) 
/* Input Buffer Disable Override */
#define Vinp_INP_DIS                (* (reg8 *) Vinp__INP_DIS)
/* LCD Common or Segment Drive */
#define Vinp_LCD_COM_SEG            (* (reg8 *) Vinp__LCD_COM_SEG)
/* Enable Segment LCD */
#define Vinp_LCD_EN                 (* (reg8 *) Vinp__LCD_EN)
/* Slew Rate Control */
#define Vinp_SLW                    (* (reg8 *) Vinp__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define Vinp_PRTDSI__CAPS_SEL       (* (reg8 *) Vinp__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define Vinp_PRTDSI__DBL_SYNC_IN    (* (reg8 *) Vinp__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define Vinp_PRTDSI__OE_SEL0        (* (reg8 *) Vinp__PRTDSI__OE_SEL0) 
#define Vinp_PRTDSI__OE_SEL1        (* (reg8 *) Vinp__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define Vinp_PRTDSI__OUT_SEL0       (* (reg8 *) Vinp__PRTDSI__OUT_SEL0) 
#define Vinp_PRTDSI__OUT_SEL1       (* (reg8 *) Vinp__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define Vinp_PRTDSI__SYNC_OUT       (* (reg8 *) Vinp__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(Vinp__SIO_CFG)
    #define Vinp_SIO_HYST_EN        (* (reg8 *) Vinp__SIO_HYST_EN)
    #define Vinp_SIO_REG_HIFREQ     (* (reg8 *) Vinp__SIO_REG_HIFREQ)
    #define Vinp_SIO_CFG            (* (reg8 *) Vinp__SIO_CFG)
    #define Vinp_SIO_DIFF           (* (reg8 *) Vinp__SIO_DIFF)
#endif /* (Vinp__SIO_CFG) */

/* Interrupt Registers */
#if defined(Vinp__INTSTAT)
    #define Vinp_INTSTAT             (* (reg8 *) Vinp__INTSTAT)
    #define Vinp_SNAP                (* (reg8 *) Vinp__SNAP)
    
	#define Vinp_0_INTTYPE_REG 		(* (reg8 *) Vinp__0__INTTYPE)
#endif /* (Vinp__INTSTAT) */

#endif /* End Pins Vinp_H */


/* [] END OF FILE */
