/*******************************************************************************
* File Name: Vr.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_Vr_H) /* Pins Vr_H */
#define CY_PINS_Vr_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "Vr_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    Vr_Write(uint8 value) ;
void    Vr_SetDriveMode(uint8 mode) ;
uint8   Vr_ReadDataReg(void) ;
uint8   Vr_Read(void) ;
void    Vr_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   Vr_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the Vr_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define Vr_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define Vr_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define Vr_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define Vr_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define Vr_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define Vr_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define Vr_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define Vr_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define Vr_MASK               Vr__MASK
#define Vr_SHIFT              Vr__SHIFT
#define Vr_WIDTH              1u

/* Interrupt constants */
#if defined(Vr__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in Vr_SetInterruptMode() function.
     *  @{
     */
        #define Vr_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define Vr_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define Vr_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define Vr_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define Vr_INTR_MASK      (0x01u)
#endif /* (Vr__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define Vr_PS                     (* (reg8 *) Vr__PS)
/* Data Register */
#define Vr_DR                     (* (reg8 *) Vr__DR)
/* Port Number */
#define Vr_PRT_NUM                (* (reg8 *) Vr__PRT) 
/* Connect to Analog Globals */                                                  
#define Vr_AG                     (* (reg8 *) Vr__AG)                       
/* Analog MUX bux enable */
#define Vr_AMUX                   (* (reg8 *) Vr__AMUX) 
/* Bidirectional Enable */                                                        
#define Vr_BIE                    (* (reg8 *) Vr__BIE)
/* Bit-mask for Aliased Register Access */
#define Vr_BIT_MASK               (* (reg8 *) Vr__BIT_MASK)
/* Bypass Enable */
#define Vr_BYP                    (* (reg8 *) Vr__BYP)
/* Port wide control signals */                                                   
#define Vr_CTL                    (* (reg8 *) Vr__CTL)
/* Drive Modes */
#define Vr_DM0                    (* (reg8 *) Vr__DM0) 
#define Vr_DM1                    (* (reg8 *) Vr__DM1)
#define Vr_DM2                    (* (reg8 *) Vr__DM2) 
/* Input Buffer Disable Override */
#define Vr_INP_DIS                (* (reg8 *) Vr__INP_DIS)
/* LCD Common or Segment Drive */
#define Vr_LCD_COM_SEG            (* (reg8 *) Vr__LCD_COM_SEG)
/* Enable Segment LCD */
#define Vr_LCD_EN                 (* (reg8 *) Vr__LCD_EN)
/* Slew Rate Control */
#define Vr_SLW                    (* (reg8 *) Vr__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define Vr_PRTDSI__CAPS_SEL       (* (reg8 *) Vr__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define Vr_PRTDSI__DBL_SYNC_IN    (* (reg8 *) Vr__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define Vr_PRTDSI__OE_SEL0        (* (reg8 *) Vr__PRTDSI__OE_SEL0) 
#define Vr_PRTDSI__OE_SEL1        (* (reg8 *) Vr__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define Vr_PRTDSI__OUT_SEL0       (* (reg8 *) Vr__PRTDSI__OUT_SEL0) 
#define Vr_PRTDSI__OUT_SEL1       (* (reg8 *) Vr__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define Vr_PRTDSI__SYNC_OUT       (* (reg8 *) Vr__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(Vr__SIO_CFG)
    #define Vr_SIO_HYST_EN        (* (reg8 *) Vr__SIO_HYST_EN)
    #define Vr_SIO_REG_HIFREQ     (* (reg8 *) Vr__SIO_REG_HIFREQ)
    #define Vr_SIO_CFG            (* (reg8 *) Vr__SIO_CFG)
    #define Vr_SIO_DIFF           (* (reg8 *) Vr__SIO_DIFF)
#endif /* (Vr__SIO_CFG) */

/* Interrupt Registers */
#if defined(Vr__INTSTAT)
    #define Vr_INTSTAT             (* (reg8 *) Vr__INTSTAT)
    #define Vr_SNAP                (* (reg8 *) Vr__SNAP)
    
	#define Vr_0_INTTYPE_REG 		(* (reg8 *) Vr__0__INTTYPE)
#endif /* (Vr__INTSTAT) */

#endif /* End Pins Vr_H */


/* [] END OF FILE */
