/*******************************************************************************
* File Name: main.c
*******************************************************************************/

#include <project.h>
#include <VDAC8.h>

#define REQUEST_PER_BURST        (1u)
#define BYTES_PER_BURST          (4u)
#define UPPER_SRC_ADDRESS        CYDEV_PERIPH_BASE
#define UPPER_DEST_ADDRESS       CYDEV_PERIPH_BASE


void DMA_Config(void);
int sprintf(char*, const char*, ...);

/*******************************************************************************
* Interrupt
*******************************************************************************/
CY_ISR(filterVDAC)
{
	VDAC8_SetValue( Filter_Read8(Filter_CHANNEL_A)^ 0x80);

}


/*******************************************************************************
* Function Name: main
*******************************************************************************/
int main()
{
    char str[10];
    int16 Vadc;
    
    /* Start all components used on schematic */
    LCD_Char_Start();
    
    ADC_DelSig_IRQ_Start();
    isr_StartEx(filterVDAC);
    ADC_DelSig_Start();
    ADC_DelSig_StartConvert();
    ADC_DelSig_SetCoherency(ADC_DelSig_COHER_HIGH);
    VDAC8_Start();
    Opamp_Start();
    PGA_1_Start();  

    Filter_Start();
    Filter_SetCoherencyEx( Filter_STAGEA_COHER, Filter_KEY_HIGH);
    Filter_SetDalign( Filter_STAGEA_DALIGN, Filter_DISABLED);

    /* User-implemented function to set-up DMA */
    DMA_Config();

    /* Enable Global Interrupts */
    CYGlobalIntEnable;
    
    for(;;)
    {
        if( Reg_Disp_Read())
        {
            Vadc = (int16)ADC_DelSig_GetResult16();
            LCD_Char_Position(0u, 0u);
            LCD_Char_PrintString("ADC : ");              
            sprintf(str,"%6i ", Vadc);       
            LCD_Char_PrintString(str);
        }
    }
} /* End of main */


/*******************************************************************************
* Function Name: DMA_Config
*******************************************************************************/
void DMA_Config(void)
{
    uint8 channelHandle;
    uint8 tdChanA;

    channelHandle = DMA_DmaInitialize(BYTES_PER_BURST, REQUEST_PER_BURST,
                    HI16(UPPER_SRC_ADDRESS), HI16(UPPER_DEST_ADDRESS));

    tdChanA = CyDmaTdAllocate();

    CyDmaTdSetConfiguration(tdChanA, 4u, tdChanA, 0 );
//    CyDmaTdSetConfiguration(tdChanA, 2u, DMA_INVALID_TD, CY_DMA_TD_SWAP_EN);
//    CyDmaTdSetConfiguration(tdChanA, 3u, DMA_INVALID_TD, CY_DMA_TD_SWAP_EN);
//    CyDmaTdSetConfiguration(tdChanA, 4u, DMA_INVALID_TD, CY_DMA_TD_SWAP_EN | CY_DMA_TD_SWAP_SIZE4);

    CyDmaTdSetAddress(tdChanA, LO16((uint32)ADC_DelSig_DEC_SAMP_PTR), 
                               LO16((uint32)Filter_STAGEAH_PTR));

    CyDmaChSetInitialTd(channelHandle, tdChanA);

    CyDmaChEnable(channelHandle, 1u);
}

/* [] END OF FILE */
